/* config.h: Prototypes and declarations for config.c
 * Copyright (C) 2014 Julian Graham
 *
 * gzochi is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GZOCHID_CONFIG_H
#define GZOCHID_CONFIG_H

#include <glib.h>

gboolean gzochid_config_to_boolean (char *, gboolean);
int gzochid_config_to_int (char *, int);
long gzochid_config_to_long (char *, long);

GHashTable *gzochid_config_keyfile_extract_config (GKeyFile *, char *);

#endif /* GZOCHID_CONFIG_H */
